#!/bin/sh
echo 'name: HUnit
version: 1.2.5.2
id: HUnit-1.2.5.2-6e02ecc15e3cc5ab8ef10df50d05a1a9

license: BSD3
copyright:
maintainer: hunit@richardg.name
stability: stable
homepage: http://hunit.sourceforge.net/
package-url:
synopsis: A unit testing framework for Haskell
description: HUnit is a unit testing framework for Haskell, inspired by the
             JUnit tool for Java, see: <http://www.junit.org>.
category: Testing
author: Dean Herington
pkgpath: devel/hs-HUnit
exposed: True
exposed-modules: Test.HUnit.Base Test.HUnit.Lang
                 Test.HUnit.Terminal Test.HUnit.Text Test.HUnit
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/HUnit-1.2.5.2
library-dirs: /usr/local/lib/ghc/HUnit-1.2.5.2
hs-libraries: HSHUnit-1.2.5.2
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.6.0.1-6b06c3defb20732cfd08deb8ba52ca7c
         deepseq-1.3.0.1-5cc4cd89bdc2e8f6db1833d95ec36926
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-HUnit-1.2.5.2/html/HUnit.haddock
haddock-html: /usr/local/share/doc/hs-HUnit-1.2.5.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
